@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.SecretsManager 1.17.67\n"
-        "Version:         1.17.67.0\n"
-        "Builder version: 4.10.0\n"
+        "Type annotations for boto3.SecretsManager 1.17.70\n"
+        "Version:         1.17.70\n"
+        "Builder version: 4.11.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-secretsmanager/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/secretsmanager.html#SecretsManager\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/secretsmanager.html#SecretsManager\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.67.0")
+    print("1.17.70")
 
 
 def main() -> None:
