@@ -1,5 +1,7 @@
 """
-Main interface for secretsmanager service literal definitions.
+Type annotations for secretsmanager service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/literals.html)
 
 Usage::
 
